Initial values for the parameters to be optimized over.
t
non-negative random variable representing the failure time and leave the snapshot failure rate, or danger.
method
The method to be used.
Value
Returns a list of summary statistics
of the fitted GTDL distribution.
References
Aarset, M. V. (1987). How to Identify a Bathtub Hazard Rate. IEEE Transactions on Reliability, 36, 106<U+2013>108.
Mackenzie, G. (1996) Regression Models for Survival Data: The Generalized Time-Dependent Logistic Family. Journal of the Royal Statistical Society.
Series D (The Statistician). 45. 21-34.